LoStatusX extension

on

Properties

isFailure → bool

Available on LoStatus, provided by the LoStatusX extension

no setter
isInvalid → bool

Available on LoStatus, provided by the LoStatusX extension

no setter
isLoading → bool

Available on LoStatus, provided by the LoStatusX extension

no setter
isMixed → bool

Available on LoStatus, provided by the LoStatusX extension

no setter
isPure → bool

Available on LoStatus, provided by the LoStatusX extension

no setter
isSubmitted → bool

Available on LoStatus, provided by the LoStatusX extension

no setter
isSuccess → bool

Available on LoStatus, provided by the LoStatusX extension

no setter
isValid → bool

Available on LoStatus, provided by the LoStatusX extension

no setter

Methods

and(LoStatus other) → LoStatus

Available on LoStatus, provided by the LoStatusX extension

Behaves like the logical and operator but for LoStatus to accumulate field statuses to compute the form status.