CheckboxProps class

Inheritance

Constructors

CheckboxProps({Key? key, required bool? value, bool tristate = false, required ValueChanged<bool?>? onChanged, MouseCursor? mouseCursor, Color? activeColor, WidgetStateProperty<Color?>? fillColor, Color? checkColor, Color? focusColor, Color? hoverColor, WidgetStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, VisualDensity? visualDensity, FocusNode? focusNode, bool autofocus = false, OutlinedBorder? shape, BorderSide? side, bool isError = false, String? semanticLabel})
const
CheckboxProps.adaptive({Key? key, required bool? value, bool tristate = false, required ValueChanged<bool?>? onChanged, MouseCursor? mouseCursor, Color? activeColor, WidgetStateProperty<Color?>? fillColor, Color? checkColor, Color? focusColor, Color? hoverColor, WidgetStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, VisualDensity? visualDensity, FocusNode? focusNode, bool autofocus = false, OutlinedBorder? shape, BorderSide? side, bool isError = false, String? semanticLabel})
const

Properties

activeColor → Color?
The color to use when this checkbox is checked.
finalinherited
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
checkColor → Color?
The color to use for the check icon when this checkbox is checked.
finalinherited
fillColor → WidgetStateProperty<Color?>?
The color that fills the checkbox, in all WidgetStates.
finalinherited
focusColor → Color?
The color for the checkbox's Material when it has the input focus.
finalinherited
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hoverColor → Color?
The color for the checkbox's Material when a pointer is hovering over it.
finalinherited
isError → bool
True if this checkbox wants to show an error state.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTapTargetSize → MaterialTapTargetSize?
Configures the minimum size of the tap target.
finalinherited
mouseCursor → MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
onChanged → ValueChanged<bool?>?
Called when the value of the checkbox should change.
finalinherited
overlayColor → WidgetStateProperty<Color?>?
The color for the checkbox's Material.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
The semantic label for the checkbox that will be announced by screen readers.
finalinherited
shape → OutlinedBorder?
The shape of the checkbox's Material.
finalinherited
side → BorderSide?
The color and width of the checkbox's border.
finalinherited
splashRadius → double?
The splash radius of the circular Material ink response.
finalinherited
tristate → bool
If true the checkbox's value can be true, false, or null.
finalinherited
value → bool?
Whether this checkbox is checked.
finalinherited
visualDensity → VisualDensity?
Defines how compact the checkbox's layout will be.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<Checkbox>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited