LoFieldValidator<T> class

Implemented types

Constructors

LoFieldValidator(ValidateFunc<T?, String> validateImpl)
LoFieldValidator.all(List<LoFieldBaseValidator<T>> validators, [String? message])
{@template LoValidator.all}
LoFieldValidator.any(List<LoFieldBaseValidator<T>> validators, [String? message])
{@template LoValidator.any}

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateImpl → ValidateFunc<T?, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(T? value) → String?
Returns String containing the error message if value is invalid. or null when value is valid.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited