LoMatchValidator<TKey> class

Inheritance

Constructors

LoMatchValidator(TKey master, TKey slave, [String message = 'Does not match'])

Properties

hashCode → int
The hash code for this object.
no setterinherited
master → TKey
The loKey of the master field
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slave → TKey
The loKey of the slave field, it will contain the error if does not match master.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(ValMap<TKey> values) → ErrMap<TKey>?
Returns ErrMap containing the error messages for each field depedning on each its value from ValMap.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited