LoRegExpValidator class

Implemented types

Constructors

LoRegExpValidator(String pattern, [String message = 'Invalid format'])
LoRegExpValidator.email([String message = 'Invalid email'])

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
final
pattern → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String? value) → String?
Returns String containing the error message if value is invalid. or null when value is valid.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited